summaryrefslogtreecommitdiff
path: root/src/api/cvc4cpp.h
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2020-10-07 10:55:29 -0700
committerGitHub <noreply@github.com>2020-10-07 12:55:29 -0500
commita6817647ee9bae0df0f1922c0d521d7f100d0245 (patch)
tree192655da9dedc67a04ef29d4eabd4c1e67c7a143 /src/api/cvc4cpp.h
parenteb4321c5040258ac1ac41eb955aa5b6b5199011e (diff)
New C++ API: Rename Term::isConst() to Term::isValue(). (#5211)
Diffstat (limited to 'src/api/cvc4cpp.h')
-rw-r--r--src/api/cvc4cpp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/api/cvc4cpp.h b/src/api/cvc4cpp.h
index c53d6f828..679f39750 100644
--- a/src/api/cvc4cpp.h
+++ b/src/api/cvc4cpp.h
@@ -958,11 +958,11 @@ class CVC4_PUBLIC Term
bool isNull() const;
/**
* Check if this is a Term representing a constant.
*
- * @return true if a constant Term
+ * @return true if this is a Term representing a value
*/
- bool isConst() const;
+ bool isValue() const;
/**
* Return the base (element stored at all indices) of a constant array
generated by cgit on debian on lair
@@ -958,11 +958,11 @@ class CVC4_PUBLIC Term
bool isNull() const;
/**
- * Check if this is a Term representing a constant.
+ * Check if this is a Term representing a value.
*
contact matthew@masot.net with questions or feedback